@@ -361,7 +361,6 @@ virt_source_upstream_version(struct varbuf *vb,
 
 	if (version.version)
 		varbuf_add_str(vb, version.version);
-	varbuf_end_str(vb);
 }
 
 static const struct fieldinfo virtinfos[] = {
@@ -428,8 +427,7 @@ pkg_format_print(struct varbuf *vb, const struct pkg_format_node *head,
 			if (fip) {
 				fip->wcall(&wb, pkg, pkgbin, 0, fip);
 
-				varbuf_end_str(&wb);
-				pkg_format_item(&fb, node, wb.buf);
+				pkg_format_item(&fb, node, varbuf_str(&wb));
 				varbuf_reset(&wb);
 				ok = true;
 			} else {
@@ -449,8 +447,7 @@ pkg_format_print(struct varbuf *vb, const struct pkg_format_node *head,
 
 			if ((width != 0) && (len > width))
 				len = width;
-			varbuf_add_buf(vb, fb.buf, len);
-			varbuf_end_str(vb);
+			varbuf_add_buf(vb, varbuf_str(&fb), len);
 		}
 
 		varbuf_reset(&fb);
