@@ -26,6 +26,7 @@
 #include <dpkg/file.h>
 
 #include <sys/types.h>
+#include <sys/stat.h>
 
 #include <errno.h>
 #include <unistd.h>
@@ -38,6 +39,20 @@ static const char ref_data[] =
 	"containing multiple lines\n"
 ;
 
+static void
+test_file_getcwd(void)
+{
+	char *env;
+	struct varbuf cwd = VARBUF_INIT;
+
+	env = getenv("abs_builddir");
+	file_getcwd(&cwd);
+
+	test_str(env, ==, cwd.buf);
+
+	varbuf_destroy(&cwd);
+}
+
 static void
 test_file_slurp(void)
 {
@@ -85,12 +100,22 @@ test_file_slurp(void)
 	test_pass(err.type == DPKG_MSG_NONE);
 	varbuf_destroy(&vb);
 
+	test_fail(file_is_exec(test_dir));
+	test_fail(file_is_exec(test_file));
+	test_pass(chmod(test_file, 0755) == 0);
+	test_pass(file_is_exec(test_file));
+	test_pass(chmod(test_file, 0750) == 0);
+	test_pass(file_is_exec(test_file));
+
 	test_pass(unlink(test_file) == 0);
+	free(test_file);
+	free(test_dir);
 }
 
 TEST_ENTRY(test)
 {
-	test_plan(26);
+	test_plan(33);
 
+	test_file_getcwd();
 	test_file_slurp();
 }
