@@ -58,7 +58,7 @@
 
 #include "main.h"
 
-enum conffopt {
+enum DPKG_ATTR_ENUM_FLAGS conffopt {
 	CFOF_PROMPT		= DPKG_BIT(0),
 	CFOF_KEEP		= DPKG_BIT(1),
 	CFOF_INSTALL		= DPKG_BIT(2),
@@ -356,7 +356,7 @@ deferred_configure_ghost_conffile(struct pkginfo *pkg, struct conffile *conff)
 
 		for (otherconff = otherpkg->installed.conffiles; otherconff;
 		     otherconff = otherconff->next) {
-			if (otherconff->obsolete || otherconff->remove_on_upgrade)
+			if (conffile_is_disappearing(otherconff))
 				continue;
 
 			/* Check if we need to propagate the new hash from
@@ -379,31 +379,31 @@ deferred_configure_conffile(struct pkginfo *pkg, struct conffile *conff)
 	int useredited, distedited;
 	enum conffopt what;
 	struct stat stab;
-	struct varbuf cdr = VARBUF_INIT, cdr2 = VARBUF_INIT;
-	char *cdr2rest;
+	struct varbuf cdr = VARBUF_INIT;
+	struct varbuf cdr_new = VARBUF_INIT;
+	struct varbuf cdr_old = VARBUF_INIT;
+	struct varbuf cdr_dist = VARBUF_INIT;
 	int rc;
 
-	usenode = namenodetouse(fsys_hash_find_node(conff->name, FHFF_NOCOPY),
+	usenode = namenodetouse(fsys_hash_find_node(conff->name, FHFF_NO_COPY),
                                 pkg, &pkg->installed);
 
 	rc = conffderef(pkg, &cdr, usenode->name);
-	if (rc == -1) {
+	if (rc < 0) {
 		conff->hash = EMPTYHASHFLAG;
 		return;
 	}
 	md5hash(pkg, currenthash, cdr.buf);
 
-	varbuf_reset(&cdr2);
-	varbuf_add_str(&cdr2, cdr.buf);
-	varbuf_end_str(&cdr2);
-	/* XXX: Make sure there's enough room for extensions. */
-	varbuf_grow(&cdr2, 50);
-	cdr2rest = cdr2.buf + strlen(cdr.buf);
-	/* From now on we can just strcpy(cdr2rest, extension); */
+	varbuf_set_varbuf(&cdr_new, &cdr);
+	varbuf_add_str(&cdr_new, DPKGNEWEXT);
+	varbuf_set_varbuf(&cdr_old, &cdr);
+	varbuf_add_str(&cdr_old, DPKGOLDEXT);
+	varbuf_set_varbuf(&cdr_dist, &cdr);
+	varbuf_add_str(&cdr_dist, DPKGDISTEXT);
 
-	strcpy(cdr2rest, DPKGNEWEXT);
 	/* If the .dpkg-new file is no longer there, ignore this one. */
-	if (lstat(cdr2.buf, &stab)) {
+	if (lstat(cdr_new.buf, &stab)) {
 		if (errno == ENOENT) {
 			/* But, sync the conffile hash value from another
 			 * package set instance. */
@@ -411,14 +411,14 @@ deferred_configure_conffile(struct pkginfo *pkg, struct conffile *conff)
 			return;
 		}
 		ohshite(_("unable to stat new distributed conffile '%.250s'"),
-		        cdr2.buf);
+		        cdr_new.buf);
 	}
-	md5hash(pkg, newdisthash, cdr2.buf);
+	md5hash(pkg, newdisthash, cdr_new.buf);
 
 	/* Copy the permissions from the installed version to the new
 	 * distributed version. */
 	if (!stat(cdr.buf, &stab))
-		file_copy_perms(cdr.buf, cdr2.buf);
+		file_copy_perms(cdr.buf, cdr_new.buf);
 	else if (errno != ENOENT)
 		ohshite(_("unable to stat current installed conffile '%.250s'"),
 		        cdr.buf);
@@ -467,60 +467,52 @@ deferred_configure_conffile(struct pkginfo *pkg, struct conffile *conff)
 	      "deferred_configure '%s' (= '%s') useredited=%d distedited=%d what=%o",
 	      usenode->name, cdr.buf, useredited, distedited, what);
 
-	what = promptconfaction(pkg, usenode->name, cdr.buf, cdr2.buf,
+	what = promptconfaction(pkg, usenode->name, cdr.buf, cdr_new.buf,
 	                        useredited, distedited, what);
 
 	switch (what & ~(CFOF_IS_NEW | CFOF_USER_DEL)) {
 	case CFO_KEEP | CFOF_BACKUP:
-		strcpy(cdr2rest, DPKGOLDEXT);
-		if (unlink(cdr2.buf) && errno != ENOENT)
+		if (unlink(cdr_old.buf) && errno != ENOENT)
 			warning(_("%s: failed to remove old backup '%.250s': %s"),
-			        pkg_name(pkg, pnaw_nonambig), cdr2.buf,
+			        pkg_name(pkg, pnaw_nonambig), cdr_old.buf,
 			        strerror(errno));
 
-		varbuf_add_str(&cdr, DPKGDISTEXT);
-		varbuf_end_str(&cdr);
-		strcpy(cdr2rest, DPKGNEWEXT);
 		trig_path_activate(usenode, pkg);
-		if (rename(cdr2.buf, cdr.buf))
+		if (rename(cdr_new.buf, cdr_dist.buf))
 			warning(_("%s: failed to rename '%.250s' to '%.250s': %s"),
-			        pkg_name(pkg, pnaw_nonambig), cdr2.buf, cdr.buf,
+			        pkg_name(pkg, pnaw_nonambig), cdr_new.buf, cdr_dist.buf,
 			        strerror(errno));
 		break;
 	case CFO_KEEP:
-		strcpy(cdr2rest, DPKGNEWEXT);
-		if (unlink(cdr2.buf))
+		if (unlink(cdr_new.buf))
 			warning(_("%s: failed to remove '%.250s': %s"),
-			        pkg_name(pkg, pnaw_nonambig), cdr2.buf,
+			        pkg_name(pkg, pnaw_nonambig), cdr_new.buf,
 			        strerror(errno));
 		break;
 	case CFO_INSTALL | CFOF_BACKUP:
-		strcpy(cdr2rest, DPKGDISTEXT);
-		if (unlink(cdr2.buf) && errno != ENOENT)
+		if (unlink(cdr_dist.buf) && errno != ENOENT)
 			warning(_("%s: failed to remove old distributed version '%.250s': %s"),
-			        pkg_name(pkg, pnaw_nonambig), cdr2.buf,
+			        pkg_name(pkg, pnaw_nonambig), cdr_dist.buf,
 			        strerror(errno));
-		strcpy(cdr2rest, DPKGOLDEXT);
-		if (unlink(cdr2.buf) && errno != ENOENT)
+		if (unlink(cdr_old.buf) && errno != ENOENT)
 			warning(_("%s: failed to remove '%.250s' (before overwrite): %s"),
-			        pkg_name(pkg, pnaw_nonambig), cdr2.buf,
+			        pkg_name(pkg, pnaw_nonambig), cdr_old.buf,
 			        strerror(errno));
 		if (!(what & CFOF_USER_DEL))
-			if (link(cdr.buf, cdr2.buf))
+			if (link(cdr.buf, cdr_old.buf))
 				warning(_("%s: failed to link '%.250s' to '%.250s': %s"),
 				        pkg_name(pkg, pnaw_nonambig), cdr.buf,
-				        cdr2.buf, strerror(errno));
+				        cdr_old.buf, strerror(errno));
 		/* Fall through. */
 	case CFO_INSTALL:
 		printf(_("Installing new version of config file %s ...\n"),
 		       usenode->name);
 		/* Fall through. */
 	case CFO_NEW_CONFF:
-		strcpy(cdr2rest, DPKGNEWEXT);
 		trig_path_activate(usenode, pkg);
-		if (rename(cdr2.buf, cdr.buf))
+		if (rename(cdr_new.buf, cdr.buf))
 			ohshite(_("unable to install '%.250s' as '%.250s'"),
-			        cdr2.buf, cdr.buf);
+			        cdr_new.buf, cdr.buf);
 		break;
 	default:
 		internerr("unknown conffopt '%d'", what);
@@ -530,7 +522,9 @@ deferred_configure_conffile(struct pkginfo *pkg, struct conffile *conff)
 	modstatdb_note(pkg);
 
 	varbuf_destroy(&cdr);
-	varbuf_destroy(&cdr2);
+	varbuf_destroy(&cdr_new);
+	varbuf_destroy(&cdr_old);
+	varbuf_destroy(&cdr_dist);
 }
 
 /**
@@ -610,15 +604,13 @@ deferred_configure(struct pkginfo *pkg)
 	ok = breakses_ok(pkg, &aemsgs) ? ok : DEP_CHECK_HALT;
 	if (ok == DEP_CHECK_HALT) {
 		sincenothing = 0;
-		varbuf_end_str(&aemsgs);
 		notice(_("dependency problems prevent configuration of %s:\n%s"),
-		       pkg_name(pkg, pnaw_nonambig), aemsgs.buf);
+		       pkg_name(pkg, pnaw_nonambig), varbuf_str(&aemsgs));
 		varbuf_destroy(&aemsgs);
 		ohshit(_("dependency problems - leaving unconfigured"));
 	} else if (aemsgs.used) {
-		varbuf_end_str(&aemsgs);
 		notice(_("%s: dependency problems, but configuring anyway as you requested:\n%s"),
-		       pkg_name(pkg, pnaw_nonambig), aemsgs.buf);
+		       pkg_name(pkg, pnaw_nonambig), varbuf_str(&aemsgs));
 	}
 	varbuf_destroy(&aemsgs);
 	sincenothing = 0;
@@ -660,7 +652,7 @@ deferred_configure(struct pkginfo *pkg)
 		 * ‘*.dpkg-new’ no longer exists we assume that we've
 		 * already processed this one. */
 		for (conff = pkg->installed.conffiles; conff; conff = conff->next) {
-			if (conff->obsolete || conff->remove_on_upgrade)
+			if (conffile_is_disappearing(conff))
 				continue;
 			deferred_configure_conffile(pkg, conff);
 		}
@@ -701,13 +693,10 @@ conffderef(struct pkginfo *pkg, struct varbuf *result, const char *in)
 {
 	static struct varbuf target = VARBUF_INIT;
 	struct stat stab;
-	ssize_t r;
 	int loopprotect;
 
-	varbuf_reset(result);
-	varbuf_add_str(result, dpkg_fsys_get_dir());
+	varbuf_set_str(result, dpkg_fsys_get_dir());
 	varbuf_add_str(result, in);
-	varbuf_end_str(result);
 
 	loopprotect = 0;
 
@@ -727,6 +716,8 @@ conffderef(struct pkginfo *pkg, struct varbuf *result, const char *in)
 			      in, result->buf);
 			return 0;
 		} else if (S_ISLNK(stab.st_mode)) {
+			ssize_t linksize;
+
 			debug(dbg_conffdetail, "conffderef symlink loopprotect=%d",
 			      loopprotect);
 			if (loopprotect++ >= 25) {
@@ -737,37 +728,35 @@ conffderef(struct pkginfo *pkg, struct varbuf *result, const char *in)
 				return -1;
 			}
 
-			varbuf_reset(&target);
-			varbuf_grow(&target, stab.st_size + 1);
-			r = readlink(result->buf, target.buf, target.size);
-			if (r < 0) {
+			linksize = file_readlink(result->buf, &target, stab.st_size);
+			if (linksize < 0) {
 				warning(_("%s: unable to readlink conffile '%s'\n"
 				          " (= '%s'): %s"),
 				        pkg_name(pkg, pnaw_nonambig), in,
 				        result->buf, strerror(errno));
 				return -1;
-			} else if (r != stab.st_size) {
+			} else if (linksize != stab.st_size) {
 				warning(_("symbolic link '%.250s' size has "
 				          "changed from %jd to %zd"),
-				        result->buf, (intmax_t)stab.st_size, r);
+				        result->buf, (intmax_t)stab.st_size,
+				        linksize);
 				/* If the returned size is smaller, let's
 				 * proceed, otherwise error out. */
-				if (r > stab.st_size)
+				if (linksize > stab.st_size)
 					return -1;
 			}
-			varbuf_trunc(&target, r);
-			varbuf_end_str(&target);
 
 			debug(dbg_conffdetail,
 			      "conffderef readlink gave %zd, '%s'",
-			      r, target.buf);
+			      linksize, target.buf);
 
 			if (target.buf[0] == '/') {
-				varbuf_reset(result);
-				varbuf_add_str(result, dpkg_fsys_get_dir());
+				varbuf_set_str(result, dpkg_fsys_get_dir());
 				debug(dbg_conffdetail,
 				      "conffderef readlink absolute");
 			} else {
+				ssize_t r;
+
 				for (r = result->used - 1; r > 0 && result->buf[r] != '/'; r--)
 					;
 				if (r < 0) {
@@ -781,11 +770,10 @@ conffderef(struct pkginfo *pkg, struct varbuf *result, const char *in)
 					r++;
 				varbuf_trunc(result, r);
 				debug(dbg_conffdetail,
-				      "conffderef readlink relative to '%.*s'",
-				      (int)result->used, result->buf);
+				      "conffderef readlink relative to '%s'",
+				      varbuf_str(result));
 			}
-			varbuf_add_buf(result, target.buf, target.used);
-			varbuf_end_str(result);
+			varbuf_add_varbuf(result, &target);
 		} else {
 			warning(_("%s: conffile '%.250s' is not a plain file or symlink (= '%s')"),
 			        pkg_name(pkg, pnaw_nonambig), in, result->buf);
